@@ -5,8 +5,8 @@ clientForAccount <- function(account) {
 
   if (isShinyappsServer(account$server)) {
     shinyAppsClient(serverUrl, account)
-  } else if (isPositCloudServer(account$server)) {
-    cloudClient(serverUrl, account)
+  } else if (isPositConnectCloudServer(account$server)) {
+    connectCloudClient(serverUrl, account)
   } else if (isSPCSServer(account$server)) {
     account$snowflakeToken <- getSnowflakeAuthToken(
       serverInfo$url,
@@ -123,7 +123,8 @@ isContentType <- function(x, contentType) {
   grepl(contentType, x, fixed = TRUE)
 }
 
-uploadCloudBundle <- function(
+
+uploadShinyappsBundle <- function(
   client,
   application_id,
   bundlePath,
@@ -153,6 +154,7 @@ uploadCloudBundle <- function(
   client$getBundle(bundle$id)
 }
 
+
 uploadBundle <- function(bundle, bundleSize, bundlePath) {
   presigned_service <- parseHttpUrl(bundle$presigned_url)
 
